@@ -270,17 +270,7 @@ class BaseResponse(object):
         url_qsl = sorted(parse_qsl(url_parsed.query))
         other_qsl = sorted(parse_qsl(other_parsed.query))
 
-        if len(url_qsl) != len(other_qsl):
-            return False
-
-        for (a_k, a_v), (b_k, b_v) in zip(url_qsl, other_qsl):
-            if a_k != b_k:
-                return False
-
-            if a_v != b_v:
-                return False
-
-        return True
+        return url_qsl == other_qsl
 
     def _should_match_querystring(self, match_querystring_argument):
         if match_querystring_argument is not _unspecified:
@@ -355,11 +345,10 @@ class Response(BaseResponse):
                 content_type = "application/json"
 
         if content_type is UNSET:
-            content_type = "text/plain"
-
-        # body must be bytes
-        if isinstance(body, six.text_type):
-            body = body.encode("utf-8")
+            if isinstance(body, six.text_type) and _has_unicode(body):
+                content_type = "text/plain; charset=utf-8"
+            else:
+                content_type = "text/plain"
 
         self.body = body
         self.status = status
@@ -408,7 +397,14 @@ class CallbackResponse(BaseResponse):
         # If the callback set a content-type remove the one
         # set in add_callback() so that we don't have multiple
         # content type values.
-        if "Content-Type" in r_headers:
+        has_content_type = False
+        if isinstance(r_headers, dict) and "Content-Type" in r_headers:
+            has_content_type = True
+        elif isinstance(r_headers, list):
+            has_content_type = any(
+                [h for h in r_headers if h and h[0].lower() == "content-type"]
+            )
+        if has_content_type:
             headers.pop("Content-Type", None)
 
         body = _handle_body(body)
